@@ -15,6 +15,8 @@ APP_NAME = os.path.split(APP_FOLDER)[-1]
 DB_FOLDER = os.path.join(APP_FOLDER, "databases")
 DB_URI = "sqlite://storage.db"
 DB_POOL_SIZE = 1
+DB_MIGRATE = True
+DB_FAKE_MIGRATE = False # maybe?
 
 # send email on regstration
 VERIFY_EMAIL = False
@@ -23,6 +25,7 @@ VERIFY_EMAIL = False
 REQUIRES_APPROVAL = False
 
 # email settings
+SMTP_SSL = False
 SMTP_SERVER = None
 SMTP_SENDER = "you@example.com"
 SMTP_LOGIN = "username:password"
